@@ -12,7 +12,7 @@
 #' @param match String, indicating with which logical operation matching
 #'   conditions should be combined. Can be `"and"` (or `"&"`), `"or"` (or `"|"`)
 #'   or `"not"` (or `"!"`).
-#' @param return_indices Logical, if `FALSE`, return the vector of rows that
+#' @param return_indices Logical, if `TRUE`, return the vector of rows that
 #'   can be used to filter the original data frame. If `FALSE` (default),
 #'   returns directly the filtered data frame instead of the row indices.
 #' @param remove_na Logical, if `TRUE`, missing values (`NA`s) are removed before
@@ -26,7 +26,6 @@
 #'   character vector (e.g. `c("x > 4", "y == 2")`) or a variable that contains
 #'   the string representation of a logical expression. These might be useful
 #'   when used in packages to avoid defining undefined global variables.
-#' @param drop_na Deprecated, please use `remove_na` instead.
 #'
 #' @return A filtered data frame, or the row indices that match the specified
 #' configuration.
@@ -101,27 +100,26 @@
 #' data_filter(mtcars, fl)
 #' @inherit data_rename seealso
 #' @export
-data_match <- function(x,
-                       to,
-                       match = "and",
-                       return_indices = FALSE,
-                       remove_na = TRUE,
-                       drop_na,
-                       ...) {
+data_match <- function(
+  x,
+  to,
+  match = "and",
+  return_indices = FALSE,
+  remove_na = TRUE,
+  ...
+) {
   if (!is.data.frame(to)) {
     to <- as.data.frame(to)
   }
   original_x <- x
 
-  ## TODO: remove deprecated argument later
-  if (!missing(drop_na)) {
-    insight::format_warning("Argument `drop_na` is deprecated. Please use `remove_na` instead.")
-    remove_na <- drop_na
-  }
-
   # evaluate
-  match <- match.arg(tolower(match), c("and", "&", "&&", "or", "|", "||", "!", "not"))
-  match <- switch(match,
+  match <- match.arg(
+    tolower(match),
+    c("and", "&", "&&", "or", "|", "||", "!", "not")
+  )
+  match <- switch(
+    match,
     `&` = ,
     `&&` = ,
     and = "and",
@@ -191,6 +189,15 @@ data_filter <- function(x, ...) {
 #' @export
 data_filter.data.frame <- function(x, ...) {
   out <- x
+
+  # convert tibble to data.frame
+  if (inherits(x, "tbl_df")) {
+    out <- as.data.frame(out, stringsAsFactors = FALSE)
+    tbl_input <- TRUE
+  } else {
+    tbl_input <- FALSE
+  }
+
   dots <- match.call(expand.dots = FALSE)[["..."]]
 
   if (any(nzchar(names(dots), keepNA = TRUE))) {
@@ -227,11 +234,17 @@ data_filter.data.frame <- function(x, ...) {
       if (!is.null(eval_symbol)) {
         # when possible to evaluate, do we have a numeric vector provided
         # as string? (e.g. `"5:10"`) - then try to coerce to numeric
-        eval_symbol_numeric <- tryCatch(eval(parse(text = eval_symbol)), error = function(e) NULL)
+        eval_symbol_numeric <- tryCatch(
+          eval(parse(text = eval_symbol)),
+          error = function(e) NULL
+        )
       }
 
       # here we go when we have a filter expression, and no numeric vector to slice
-      if (is.null(eval_symbol) || (!is.numeric(eval_symbol) && !is.numeric(eval_symbol_numeric))) {
+      if (
+        is.null(eval_symbol) ||
+          (!is.numeric(eval_symbol) && !is.numeric(eval_symbol_numeric))
+      ) {
         # could be evaluated? Then filter expression is a string and we need
         # to convert into symbol
         if (is.character(eval_symbol)) {
@@ -245,10 +258,15 @@ data_filter.data.frame <- function(x, ...) {
         )
       } else if (is.numeric(eval_symbol)) {
         # if symbol could be evaluated and is numeric, slice
-        out <- tryCatch(out[eval_symbol, , drop = FALSE], error = function(e) NULL)
+        out <- tryCatch(out[eval_symbol, , drop = FALSE], error = function(e) {
+          NULL
+        })
       } else if (is.numeric(eval_symbol_numeric)) {
         # if symbol could be evaluated, was string and could be converted to numeric, slice
-        out <- tryCatch(out[eval_symbol_numeric, , drop = FALSE], error = function(e) NULL)
+        out <- tryCatch(
+          out[eval_symbol_numeric, , drop = FALSE],
+          error = function(e) NULL
+        )
       }
 
       if (inherits(out, "simpleError")) {
@@ -259,7 +277,11 @@ data_filter.data.frame <- function(x, ...) {
           # some syntax errors do not relate to misspelled variables...
           if (!error_var %in% colnames(x)) {
             insight::format_error(
-              paste0("Variable \"", error_var, "\" was not found in the dataset."),
+              paste0(
+                "Variable \"",
+                error_var,
+                "\" was not found in the dataset."
+              ),
               .misspelled_string(colnames(x), error_var, "Possibly misspelled?")
             )
           }
@@ -283,15 +305,30 @@ data_filter.data.frame <- function(x, ...) {
 
   # add back custom attributes
   out <- .replace_attrs(out, attributes(x))
+
+  # add back tidyverse attributes
+  if (isTRUE(tbl_input)) {
+    class(out) <- c("tbl_df", "tbl", "data.frame")
+  }
+
   out
 }
 
 
 #' @export
 data_filter.grouped_df <- function(x, ...) {
+  original_x <- x
   grps <- attr(x, "groups", exact = TRUE)
   grps <- grps[[".rows"]]
 
+  # Remove tidyverse attributes, will add them back at the end
+  if (inherits(x, "tbl_df")) {
+    tbl_input <- TRUE
+    x <- as.data.frame(x, stringsAsFactors = FALSE)
+  } else {
+    tbl_input <- FALSE
+  }
+
   dots <- match.call(expand.dots = FALSE)[["..."]]
   out <- lapply(grps, function(grp) {
     arguments <- list(x[grp, ])
@@ -305,6 +342,14 @@ data_filter.grouped_df <- function(x, ...) {
     rownames(out) <- NULL
   }
 
+  # add back tidyverse attributes
+  if (isTRUE(tbl_input)) {
+    class(out) <- c("tbl_df", "tbl", "data.frame")
+  }
+
+  # add back custom attributes
+  out <- .replace_attrs(out, attributes(original_x))
+
   out
 }
 
@@ -330,7 +375,12 @@ data_filter.grouped_df <- function(x, ...) {
   # can identify a function call, and only continue checking for wrong syntax
   # when we have not identified a function.
 
-  if (!is.function(try(get(gsub("^(.*?)\\((.*)", "\\1", tmp)), silent = TRUE))) {
+  if (
+    !is.function(tryCatch(
+      get(gsub("^(.*?)\\((.*)", "\\1", tmp)),
+      error = function(e) NULL
+    ))
+  ) {
     # Give more informative message to users
     # about possible misspelled comparisons / logical conditions
     # check if "=" instead of "==" was used?
@@ -352,7 +402,9 @@ data_filter.grouped_df <- function(x, ...) {
         paste0(
           "Filtering did not work. Please check if you need `",
           substr(logical_operator, 0, 1),
-          "` (instead of `", logical_operator, "`) as logical operator."
+          "` (instead of `",
+          logical_operator,
+          "`) as logical operator."
         )
       )
     }
