@@ -184,21 +184,27 @@ recode_values <- function(x, ...) {
 recode_values.default <- function(x, verbose = TRUE, ...) {
   if (isTRUE(verbose)) {
     insight::format_alert(
-      paste0("Variables of class `", class(x)[1], "` can't be recoded and remain unchanged.")
+      paste0(
+        "Variables of class `",
+        class(x)[1],
+        "` can't be recoded and remain unchanged."
+      )
     )
   }
-  return(x)
+  x
 }
 
 
 #' @rdname recode_values
 #' @export
-recode_values.numeric <- function(x,
-                                  recode = NULL,
-                                  default = NULL,
-                                  preserve_na = TRUE,
-                                  verbose = TRUE,
-                                  ...) {
+recode_values.numeric <- function(
+  x,
+  recode = NULL,
+  default = NULL,
+  preserve_na = TRUE,
+  verbose = TRUE,
+  ...
+) {
   # save
   original_x <- x
 
@@ -251,7 +257,10 @@ recode_values.numeric <- function(x,
       # contain values, like "1:10" or "1, 2, 3, 4". These should now be in the
       # format "c(1, 2, 3, 4)" or "c(1:10)", and it should be possible to parse
       # and evaluate these strings into a numeric vector
-      old_values <- tryCatch(eval(parse(text = old_values)), error = function(e) NULL)
+      old_values <- tryCatch(
+        eval(parse(text = old_values)),
+        error = function(e) NULL
+      )
     }
 
     if (!is.null(old_values) && (is.numeric(old_values) || is.na(old_values))) {
@@ -274,12 +283,14 @@ recode_values.numeric <- function(x,
 
 
 #' @export
-recode_values.factor <- function(x,
-                                 recode = NULL,
-                                 default = NULL,
-                                 preserve_na = TRUE,
-                                 verbose = TRUE,
-                                 ...) {
+recode_values.factor <- function(
+  x,
+  recode = NULL,
+  default = NULL,
+  preserve_na = TRUE,
+  verbose = TRUE,
+  ...
+) {
   # save
   original_x <- x
 
@@ -316,7 +327,10 @@ recode_values.factor <- function(x,
       # name of list element is old value
 
       old_values <- paste(
-        deparse(insight::trim_ws(unlist(strsplit(i, ",", fixed = TRUE), use.names = FALSE))),
+        deparse(insight::trim_ws(unlist(
+          strsplit(i, ",", fixed = TRUE),
+          use.names = FALSE
+        ))),
         collapse = ","
       )
 
@@ -324,7 +338,10 @@ recode_values.factor <- function(x,
       # contain values, like "a" or "a, b, c". These should now be in the
       # format "c("a", "b", "c")" and it should be possible to parse
       # and evaluate these strings into a numeric vector
-      old_values <- tryCatch(eval(parse(text = old_values)), error = function(e) NULL)
+      old_values <- tryCatch(
+        eval(parse(text = old_values)),
+        error = function(e) NULL
+      )
 
       # recode
       x[which(original_x %in% old_values)] <- recode[[i]]
@@ -336,7 +353,10 @@ recode_values.factor <- function(x,
       # check input style: "a, b, c"
       if (length(old_values) == 1 && grepl(",", old_values, fixed = TRUE)) {
         # split and make character vector
-        old_values <- insight::trim_ws(unlist(strsplit(old_values, ",", fixed = TRUE), use.names = FALSE))
+        old_values <- insight::trim_ws(unlist(
+          strsplit(old_values, ",", fixed = TRUE),
+          use.names = FALSE
+        ))
       }
       # recode
       if (identical(i, "NA")) {
@@ -365,12 +385,14 @@ recode_values.factor <- function(x,
 
 
 #' @export
-recode_values.character <- function(x,
-                                    recode = NULL,
-                                    default = NULL,
-                                    preserve_na = TRUE,
-                                    verbose = TRUE,
-                                    ...) {
+recode_values.character <- function(
+  x,
+  recode = NULL,
+  default = NULL,
+  preserve_na = TRUE,
+  verbose = TRUE,
+  ...
+) {
   # save
   original_x <- x
 
@@ -405,7 +427,10 @@ recode_values.character <- function(x,
 
       # name of list element is old value
       value_string <- paste(
-        deparse(insight::trim_ws(unlist(strsplit(i, ",", fixed = TRUE), use.names = FALSE))),
+        deparse(insight::trim_ws(unlist(
+          strsplit(i, ",", fixed = TRUE),
+          use.names = FALSE
+        ))),
         collapse = ","
       )
 
@@ -413,7 +438,10 @@ recode_values.character <- function(x,
       # contain values, like "a" or "a, b, c". These should now be in the
       # format "c("a", "b", "c")" and it should be possible to parse
       # and evaluate these strings into a numeric vector
-      old_values <- tryCatch(eval(parse(text = value_string)), error = function(e) NULL)
+      old_values <- tryCatch(
+        eval(parse(text = value_string)),
+        error = function(e) NULL
+      )
 
       # recode
       x[which(original_x %in% old_values)] <- recode[[i]]
@@ -425,7 +453,10 @@ recode_values.character <- function(x,
       # check input style: "a, b, c"
       if (length(old_values) == 1 && grepl(",", old_values, fixed = TRUE)) {
         # split and make character vector
-        old_values <- insight::trim_ws(unlist(strsplit(old_values, ",", fixed = TRUE), use.names = FALSE))
+        old_values <- insight::trim_ws(unlist(
+          strsplit(old_values, ",", fixed = TRUE),
+          use.names = FALSE
+        ))
       }
       # recode
       if (identical(i, "NA")) {
@@ -452,19 +483,22 @@ recode_values.character <- function(x,
 
 #' @rdname recode_values
 #' @export
-recode_values.data.frame <- function(x,
-                                     select = NULL,
-                                     exclude = NULL,
-                                     recode = NULL,
-                                     default = NULL,
-                                     preserve_na = TRUE,
-                                     append = FALSE,
-                                     ignore_case = FALSE,
-                                     regex = FALSE,
-                                     verbose = TRUE,
-                                     ...) {
+recode_values.data.frame <- function(
+  x,
+  select = NULL,
+  exclude = NULL,
+  recode = NULL,
+  default = NULL,
+  preserve_na = TRUE,
+  append = FALSE,
+  ignore_case = FALSE,
+  regex = FALSE,
+  verbose = TRUE,
+  ...
+) {
   # evaluate arguments
-  select <- .select_nse(select,
+  select <- .select_nse(
+    select,
     x,
     exclude,
     ignore_case,
@@ -512,7 +546,9 @@ recode_values.data.frame <- function(x,
   # skip if all NA
   if (!length(valid)) {
     if (isTRUE(verbose)) {
-      insight::format_warning("Variable contains only missing values. No recoding carried out.")
+      insight::format_warning(
+        "Variable contains only missing values. No recoding carried out."
+      )
     }
     ok <- FALSE
   }
@@ -520,7 +556,9 @@ recode_values.data.frame <- function(x,
   # warn if not a list
   if (!is.list(recode) || is.null(names(recode))) {
     if (isTRUE(verbose)) {
-      insight::format_warning("`recode` needs to be a (named) list. No recoding carried out.")
+      insight::format_warning(
+        "`recode` needs to be a (named) list. No recoding carried out."
+      )
     }
     ok <- FALSE
   }
