@@ -1,9 +1,17 @@
 # Code adapted from {poorman} by Nathan Eastwood [License: MIT]
 # https://github.com/nathaneastwood/poorman/blob/master/R/select_positions.R
 
-.select_nse <- function(select, data, exclude, ignore_case, regex = FALSE,
-                        remove_group_var = FALSE, allow_rename = FALSE,
-                        verbose = FALSE, ifnotfound = "warn") {
+.select_nse <- function(
+  select,
+  data,
+  exclude,
+  ignore_case,
+  regex = FALSE,
+  remove_group_var = FALSE,
+  allow_rename = FALSE,
+  verbose = FALSE,
+  ifnotfound = "warn"
+) {
   .check_data(data)
   columns <- colnames(data)
 
@@ -122,23 +130,37 @@
 
   type <- typeof(x)
 
-  out <- switch(type,
+  out <- switch(
+    type,
     integer = x,
     double = as.integer(x),
     character = .select_char(
-      data, x, ignore_case,
-      regex = regex, verbose, ifnotfound
+      data,
+      x,
+      ignore_case,
+      regex = regex,
+      verbose,
+      ifnotfound
     ),
     symbol = .select_symbol(
-      data, x, ignore_case,
-      regex = regex, verbose, ifnotfound
+      data,
+      x,
+      ignore_case,
+      regex = regex,
+      verbose,
+      ifnotfound
     ),
     language = .eval_call(
-      data, x, ignore_case,
-      regex = regex, verbose, ifnotfound
+      data,
+      x,
+      ignore_case,
+      regex = regex,
+      verbose,
+      ifnotfound
     ),
     insight::format_error(paste0(
-      "Expressions of type <", typeof(x),
+      "Expressions of type <",
+      typeof(x),
       "> cannot be evaluated for use when subsetting."
     ))
   )
@@ -171,7 +193,13 @@
     colon_vars <- unlist(strsplit(x, ":", fixed = TRUE))
     colon_match <- match(colon_vars, columns)
     if (anyNA(colon_match)) {
-      .action_if_not_found(colon_vars, columns, colon_match, verbose, ifnotfound)
+      .action_if_not_found(
+        colon_vars,
+        columns,
+        colon_match,
+        verbose,
+        ifnotfound
+      )
       matches <- NA
     } else {
       start_pos <- match(colon_vars[1], columns)
@@ -199,11 +227,7 @@
 
 # small helper, to avoid duplicated code
 
-.action_if_not_found <- function(x,
-                                 columns,
-                                 matches,
-                                 verbose,
-                                 ifnotfound) {
+.action_if_not_found <- function(x, columns, matches, verbose, ifnotfound) {
   msg <- paste0(
     "Following variable(s) were not found: ",
     toString(x[is.na(matches)])
@@ -236,7 +260,11 @@
 # it is a select helper that we grab from the error message.
 
 .select_symbol <- function(data, x, ignore_case, regex, verbose, ifnotfound) {
-  try_eval <- try(eval(x), silent = TRUE)
+  # We use `tryCatch()` instead of `try()` here, because for grouped data frame
+  # methods, `.dynEval()` can be called many times. Since `tryCatch()` is minimal
+  # faster than `try()`, we get a performance "boost" of some seconds for large
+  # data frames with many groups (see https://github.com/easystats/datawizard/pull/657/)
+  try_eval <- tryCatch(eval(x), error = function(e) NULL)
   x_dep <- insight::safe_deparse(x)
   is_select_helper <- FALSE
   out <- NULL
@@ -256,7 +284,9 @@
 
         # if starts_with() et al. come from tidyselect but need to be used in
         # a select environment, then the error doesn't have the same structure.
-        if (is.null(fn) && grepl("must be used within a", e$message, fixed = TRUE)) {
+        if (
+          is.null(fn) && grepl("must be used within a", e$message, fixed = TRUE)
+        ) {
           call_trace <- lapply(e$trace$call, function(x) {
             tmp <- insight::safe_deparse(x)
             if (grepl(paste0("^", .regex_select_helper()), tmp)) {
@@ -279,7 +309,12 @@
     # .dynGet can return "x" infinitely so we try to evaluate this arg
     # see #414
     if (!is.null(new_expr) && insight::safe_deparse(new_expr) == "x") {
-      new_expr <- .dynEval(x, inherits = FALSE, minframe = 0L, remove_n_top_env = 4)
+      new_expr <- .dynEval(
+        x,
+        inherits = FALSE,
+        minframe = 0L,
+        remove_n_top_env = 4
+      )
     }
 
     if (is_select_helper) {
@@ -295,15 +330,18 @@
     } else if (length(new_expr) == 1L && is.function(new_expr)) {
       out <- which(vapply(data, new_expr, FUN.VALUE = logical(1L)))
     } else {
-      out <- unlist(lapply(
-        new_expr,
-        .eval_expr,
-        data = data,
-        ignore_case = ignore_case,
-        regex = regex,
-        verbose = verbose,
-        ifnotfound = ifnotfound
-      ), use.names = FALSE)
+      out <- unlist(
+        lapply(
+          new_expr,
+          .eval_expr,
+          data = data,
+          ignore_case = ignore_case,
+          regex = regex,
+          verbose = verbose,
+          ifnotfound = ifnotfound
+        ),
+        use.names = FALSE
+      )
     }
   }
 
@@ -322,13 +360,19 @@
 
 .eval_call <- function(data, x, ignore_case, regex, verbose, ifnotfound) {
   type <- insight::safe_deparse(x[[1]])
-  switch(type,
+  switch(
+    type,
     `:` = .select_seq(x, data, ignore_case, regex, verbose, ifnotfound),
     `-` = .select_minus(x, data, ignore_case, regex, verbose, ifnotfound),
     `c` = .select_c(x, data, ignore_case, regex, verbose, ifnotfound), # nolint
     `(` = .select_bracket(x, data, ignore_case, regex, verbose, ifnotfound),
     `[` = .select_square_bracket(
-      x, data, ignore_case, regex, verbose, ifnotfound
+      x,
+      data,
+      ignore_case,
+      regex,
+      verbose,
+      ifnotfound
     ),
     `$` = .select_dollar(x, data, ignore_case, regex, verbose, ifnotfound),
     `~` = .select_tilde(x, data, ignore_case, regex, verbose, ifnotfound),
@@ -385,19 +429,29 @@
 .select_c <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
   lst_expr <- as.list(expr)
   lst_expr[[1]] <- NULL
-  unlist(lapply(
-    lst_expr,
-    .eval_expr,
-    data,
-    ignore_case = ignore_case,
-    regex = regex,
-    verbose = verbose,
-    ifnotfound = ifnotfound
-  ), use.names = FALSE)
+  unlist(
+    lapply(
+      lst_expr,
+      .eval_expr,
+      data,
+      ignore_case = ignore_case,
+      regex = regex,
+      verbose = verbose,
+      ifnotfound = ifnotfound
+    ),
+    use.names = FALSE
+  )
 }
 
 # e.g -(gear:cyl)
-.select_bracket <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
+.select_bracket <- function(
+  expr,
+  data,
+  ignore_case,
+  regex,
+  verbose,
+  ifnotfound
+) {
   .eval_expr(
     expr[[2]],
     data,
@@ -409,7 +463,14 @@
 }
 
 # e.g myvector[3]
-.select_square_bracket <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
+.select_square_bracket <- function(
+  expr,
+  data,
+  ignore_case,
+  regex,
+  verbose,
+  ifnotfound
+) {
   first_obj <- .eval_expr(
     expr[[2]],
     data,
@@ -441,20 +502,35 @@
 }
 
 # e.g starts_with("Sep")
-.select_helper <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
+.select_helper <- function(
+  expr,
+  data,
+  ignore_case,
+  regex,
+  verbose,
+  ifnotfound
+) {
   lst_expr <- as.list(expr)
 
   # need this if condition to distinguish between starts_with("Sep") (that we
   # can use directly) and starts_with(i) (where we need to get i)
   if (length(lst_expr) == 2L && typeof(lst_expr[[2]]) == "symbol") {
-    collapsed_patterns <- .dynGet(lst_expr[[2]], inherits = FALSE, minframe = 0L)
+    collapsed_patterns <- .dynGet(
+      lst_expr[[2]],
+      inherits = FALSE,
+      minframe = 0L
+    )
   } else {
-    collapsed_patterns <- paste(unlist(lst_expr[2:length(lst_expr)]), collapse = "|")
+    collapsed_patterns <- paste(
+      unlist(lst_expr[2:length(lst_expr)]),
+      collapse = "|"
+    )
   }
 
   helper <- insight::safe_deparse(lst_expr[[1]])
 
-  rgx <- switch(helper,
+  rgx <- switch(
+    helper,
     starts_with = paste0("^(", collapsed_patterns, ")"),
     ends_with = paste0("(", collapsed_patterns, ")$"),
     contains = paste0("(", collapsed_patterns, ")"),
@@ -469,8 +545,20 @@
 }
 
 # e.g args$select (happens when we use grouped_data (see center.grouped_df()))
-.select_dollar <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
-  first_obj <- .dynGet(expr[[2]], ifnotfound = NULL, inherits = FALSE, minframe = 0L)
+.select_dollar <- function(
+  expr,
+  data,
+  ignore_case,
+  regex,
+  verbose,
+  ifnotfound
+) {
+  first_obj <- .dynGet(
+    expr[[2]],
+    ifnotfound = NULL,
+    inherits = FALSE,
+    minframe = 0L
+  )
   if (is.null(first_obj)) {
     first_obj <- .dynEval(expr[[2]], inherits = FALSE, minframe = 0L)
   }
@@ -487,33 +575,46 @@
 # e.g ~ gear + cyl
 .select_tilde <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
   vars <- all.vars(expr)
-  unlist(lapply(
-    vars,
-    .eval_expr,
-    data = data,
-    ignore_case = ignore_case,
-    regex = regex,
-    verbose = verbose,
-    ifnotfound = ifnotfound
-  ), use.names = FALSE)
+  unlist(
+    lapply(
+      vars,
+      .eval_expr,
+      data = data,
+      ignore_case = ignore_case,
+      regex = regex,
+      verbose = verbose,
+      ifnotfound = ifnotfound
+    ),
+    use.names = FALSE
+  )
 }
 
 # e.g list(gear = 4, cyl = 5)
 .select_list <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
   vars <- names(.dynEval(expr, inherits = FALSE, minframe = 0L))
-  unlist(lapply(
-    vars,
-    .eval_expr,
-    data = data,
-    ignore_case = ignore_case,
-    regex = regex,
-    verbose = verbose,
-    ifnotfound = ifnotfound
-  ), use.names = FALSE)
+  unlist(
+    lapply(
+      vars,
+      .eval_expr,
+      data = data,
+      ignore_case = ignore_case,
+      regex = regex,
+      verbose = verbose,
+      ifnotfound = ifnotfound
+    ),
+    use.names = FALSE
+  )
 }
 
 # e.g is.numeric()
-.select_context <- function(expr, data, ignore_case, regex, verbose, ifnotfound) {
+.select_context <- function(
+  expr,
+  data,
+  ignore_case,
+  regex,
+  verbose,
+  ifnotfound
+) {
   x_dep <- insight::safe_deparse(expr)
   if (endsWith(x_dep, "()")) {
     new_expr <- gsub("\\(\\)$", "", x_dep)
@@ -588,10 +689,16 @@
 
 # Almost identical to dynGet(). The difference is that we deparse the expression
 # because get0() allows symbol only since R 4.1.0
-.dynGet <- function(x,
-                    ifnotfound = stop(gettextf("%s not found", sQuote(x)), domain = NA, call. = FALSE),
-                    minframe = 1L,
-                    inherits = FALSE) {
+.dynGet <- function(
+  x,
+  ifnotfound = stop(
+    gettextf("%s not found", sQuote(x)),
+    domain = NA,
+    call. = FALSE
+  ),
+  minframe = 1L,
+  inherits = FALSE
+) {
   x <- insight::safe_deparse(x)
   n <- sys.nframe()
   myObj <- structure(list(.b = as.raw(7)), foo = 47L)
@@ -611,19 +718,39 @@
 # error. Returns NULL if can never be evaluated.
 #
 # Custom arg "remove_n_top_env" to remove the first environments which are
-# ".select_nse()" and the other custom functions
-.dynEval <- function(x,
-                     ifnotfound = stop(gettextf("%s not found", sQuote(x)), domain = NA, call. = FALSE),
-                     minframe = 1L,
-                     inherits = FALSE,
-                     remove_n_top_env = 0) {
+# ".select_nse()" and the other custom functions.
+#
+# Arg "data" is here if we want to start searching in the data instead of the
+# lowest environment.
+.dynEval <- function(
+  x,
+  ifnotfound = stop(
+    gettextf("%s not found", sQuote(x)),
+    domain = NA,
+    call. = FALSE
+  ),
+  minframe = 1L,
+  inherits = FALSE,
+  remove_n_top_env = 0,
+  data = NULL
+) {
+  iter <- 0
   n <- sys.nframe() - remove_n_top_env
   x <- insight::safe_deparse(x)
   while (n > minframe) {
-    n <- n - 1L
-    env <- sys.frame(n)
-    r <- try(eval(str2lang(x), envir = env), silent = TRUE)
-    if (!inherits(r, "try-error") && !is.null(r)) {
+    if (iter == 0 && !is.null(data)) {
+      env <- data
+      iter <- iter + 1
+    } else {
+      n <- n - 1L
+      env <- sys.frame(n)
+    }
+    # We use `tryCatch()` instead of `try()` here, because for grouped data frame
+    # methods, `.dynEval()` can be called many times. Since `tryCatch()` is minimal
+    # faster than `try()`, we get a performance "boost" of some seconds for large
+    # data frames with many groups (see https://github.com/easystats/datawizard/pull/657/)
+    r <- tryCatch(eval(str2lang(x), envir = env), error = function(e) NULL)
+    if (!is.null(r)) {
       return(r)
     }
   }
