@@ -3,7 +3,12 @@
 # to the transformed vector
 
 #' @keywords internal
-.set_back_labels <- function(new, old, include_values = TRUE, reverse_values = FALSE) {
+.set_back_labels <- function(
+  new,
+  old,
+  include_values = TRUE,
+  reverse_values = FALSE
+) {
   # labelled data?
   attr(new, "label") <- attr(old, "label", exact = TRUE)
   value_labels <- attr(old, "labels", exact = TRUE)
@@ -11,15 +16,24 @@
   if (isTRUE(include_values) && !is.null(value_labels)) {
     if (reverse_values) {
       # reverse values? Used for "reverse_scale()"
-      attr(new, "labels") <- stats::setNames(rev(value_labels), names(value_labels))
+      attr(new, "labels") <- stats::setNames(
+        rev(value_labels),
+        names(value_labels)
+      )
     } else if (is.numeric(new)) {
       # keep value oder? Used for "to_numeric()"
       if (any(grepl("[^0-9]", value_labels))) {
         # if we have any non-numeric characters, convert to numeric
-        attr(new, "labels") <- stats::setNames(as.numeric(as.factor(value_labels)), names(value_labels))
+        attr(new, "labels") <- stats::setNames(
+          as.numeric(as.factor(value_labels)),
+          names(value_labels)
+        )
       } else {
         # if we have numeric, or "numeric character" (like "1", "2", "3" etc.)
-        attr(new, "labels") <- stats::setNames(as.numeric(value_labels), names(value_labels))
+        attr(new, "labels") <- stats::setNames(
+          as.numeric(value_labels),
+          names(value_labels)
+        )
       }
     } else {
       attr(new, "labels") <- stats::setNames(value_labels, names(value_labels))
@@ -68,7 +82,10 @@
   value_labels <- value_labels[value_labels %in% levels(x)]
 
   # for levels that have no label, we just keep the original factor level
-  value_labels <- c(value_labels, stats::setNames(missing_levels, missing_levels))
+  value_labels <- c(
+    value_labels,
+    stats::setNames(missing_levels, missing_levels)
+  )
 
   # now we can add back levels
   levels(x) <- names(value_labels)[order(as.numeric(value_labels))]
