@@ -27,6 +27,29 @@ test_that("data_codebook NaN and Inf", {
 })
 
 
+test_that("data_codebook, tinytable", {
+  skip_if_not_installed("tinytable")
+  d <- data.frame(
+    x = c(1, 4, NA, Inf, 4, NaN, 2, 1, 1)
+  )
+  expect_snapshot(display(data_codebook(d), format = "tt"))
+
+  set.seed(123)
+  d <- data.frame(
+    x = c(sample.int(15, 100, TRUE), Inf, Inf)
+  )
+  expect_snapshot(display(data_codebook(d), format = "tt"))
+  expect_snapshot(display(data_codebook(d, range_at = 100), format = "tt"))
+  expect_snapshot(display(
+    data_codebook(d, range_at = 100, max_values = 4),
+    format = "tt"
+  ))
+
+  data(iris)
+  expect_snapshot(display(data_codebook(iris[c(1, 2, 5, 3, 4)]), format = "tt"))
+})
+
+
 test_that("data_codebook iris, select", {
   expect_snapshot(data_codebook(iris, select = starts_with("Sepal")))
 })
@@ -39,8 +62,16 @@ test_that("data_codebook iris, select, ID", {
 
 test_that("data_codebook efc", {
   expect_snapshot(print(data_codebook(efc), table_width = Inf))
-  expect_snapshot(print(data_codebook(efc), table_width = "auto", remove_duplicates = FALSE))
-  expect_snapshot(print(data_codebook(efc), table_width = "auto", remove_duplicates = TRUE))
+  expect_snapshot(print(
+    data_codebook(efc),
+    table_width = "auto",
+    remove_duplicates = FALSE
+  ))
+  expect_snapshot(print(
+    data_codebook(efc),
+    table_width = "auto",
+    remove_duplicates = TRUE
+  ))
 })
 
 
@@ -161,10 +192,14 @@ test_that("data_codebook, tagged NA", {
   skip_if_not_installed("haven")
   x <- haven::labelled(
     x = c(
-      1:3, haven::tagged_na("a", "c", "z"),
-      4:1, haven::tagged_na("a", "a", "c"),
-      1:3, haven::tagged_na("z", "c", "c"),
-      1:4, haven::tagged_na("a", "c", "z")
+      1:3,
+      haven::tagged_na("a", "c", "z"),
+      4:1,
+      haven::tagged_na("a", "a", "c"),
+      1:3,
+      haven::tagged_na("z", "c", "c"),
+      1:4,
+      haven::tagged_na("a", "c", "z")
     ),
     labels = c(
       Agreement = 1,
@@ -178,10 +213,14 @@ test_that("data_codebook, tagged NA", {
 
   x <- haven::labelled(
     x = c(
-      1:3, haven::tagged_na("a", "c"),
-      4:1, haven::tagged_na("a", "a", "c"),
-      1:3, haven::tagged_na("c", "c"),
-      1:4, haven::tagged_na("a", "c")
+      1:3,
+      haven::tagged_na("a", "c"),
+      4:1,
+      haven::tagged_na("a", "a", "c"),
+      1:3,
+      haven::tagged_na("c", "c"),
+      1:4,
+      haven::tagged_na("a", "c")
     ),
     labels = c(
       Agreement = 1,
@@ -207,3 +246,12 @@ test_that("data_codebook, negative label values #334", {
   )
   expect_snapshot(data_codebook(data.frame(x1, x2)))
 })
+
+
+test_that("data_codebook, informative warning if no match", {
+  data(iris)
+  expect_warning(
+    data_codebook(iris, select = starts_with("abc")),
+    regex = "No column names that matched"
+  )
+})
