@@ -36,52 +36,99 @@ test_that("rescale works as expected", {
   expect_snapshot(head(rescale(iris, to = c(0, 1), select = "Sepal.Length")))
 
   expect_snapshot(
-    head(rescale(iris, to = list(
-      Sepal.Length = c(0, 1),
-      Petal.Length = c(-1, 0)
-    )))
+    head(rescale(
+      iris,
+      to = list(
+        Sepal.Length = c(0, 1),
+        Petal.Length = c(-1, 0)
+      )
+    ))
   )
 })
 
 
-
 test_that("rescale works with select helpers", {
   out <- rescale(iris, to = c(0, 1), select = c("Sepal.Width", "Sepal.Length"))
-  expect_equal(head(out$Sepal.Width), c(0.625, 0.41667, 0.5, 0.45833, 0.66667, 0.79167), tolerance = 1e-3)
-  expect_equal(head(out$Petal.Length), head(iris$Petal.Length), tolerance = 1e-3)
+  expect_equal(
+    head(out$Sepal.Width),
+    c(0.625, 0.41667, 0.5, 0.45833, 0.66667, 0.79167),
+    tolerance = 1e-3
+  )
+  expect_equal(
+    head(out$Petal.Length),
+    head(iris$Petal.Length),
+    tolerance = 1e-3
+  )
 
   # check class attributes
   expect_identical(
     vapply(out, class, character(1)),
     c(
-      Sepal.Length = "numeric", Sepal.Width = "numeric", Petal.Length = "numeric",
-      Petal.Width = "numeric", Species = "factor"
+      Sepal.Length = "numeric",
+      Sepal.Width = "numeric",
+      Petal.Length = "numeric",
+      Petal.Width = "numeric",
+      Species = "factor"
     )
   )
 
   out <- rescale(iris, to = c(0, 1), select = starts_with("Sepal"))
-  expect_equal(head(out$Sepal.Width), c(0.625, 0.41667, 0.5, 0.45833, 0.66667, 0.79167), tolerance = 1e-3)
-  expect_equal(head(out$Petal.Length), head(iris$Petal.Length), tolerance = 1e-3)
+  expect_equal(
+    head(out$Sepal.Width),
+    c(0.625, 0.41667, 0.5, 0.45833, 0.66667, 0.79167),
+    tolerance = 1e-3
+  )
+  expect_equal(
+    head(out$Petal.Length),
+    head(iris$Petal.Length),
+    tolerance = 1e-3
+  )
 
   skip_if_not_installed("poorman")
 
   x <- poorman::group_by(iris, Species)
   out <- rescale(x, to = c(0, 1), select = starts_with("Sepal"))
-  expect_equal(head(out$Sepal.Width), c(0.57143, 0.33333, 0.42857, 0.38095, 0.61905, 0.7619), tolerance = 1e-3)
-  expect_equal(head(out$Petal.Length), head(iris$Petal.Length), tolerance = 1e-3)
+  expect_equal(
+    head(out$Sepal.Width),
+    c(0.57143, 0.33333, 0.42857, 0.38095, 0.61905, 0.7619),
+    tolerance = 1e-3
+  )
+  expect_equal(
+    head(out$Petal.Length),
+    head(iris$Petal.Length),
+    tolerance = 1e-3
+  )
 })
 
 
 # grouped df ------------------------------
 test_that("rescale works grouped df and append", {
-  out <- rescale(iris, to = c(0, 1), select = c("Sepal.Width", "Sepal.Length"), append = TRUE)
-  expect_equal(head(out$Sepal.Width_r), c(0.625, 0.41667, 0.5, 0.45833, 0.66667, 0.79167), tolerance = 1e-3)
-  expect_equal(head(out$Petal.Length), head(iris$Petal.Length), tolerance = 1e-3)
+  out <- rescale(
+    iris,
+    to = c(0, 1),
+    select = c("Sepal.Width", "Sepal.Length"),
+    append = TRUE
+  )
+  expect_equal(
+    head(out$Sepal.Width_r),
+    c(0.625, 0.41667, 0.5, 0.45833, 0.66667, 0.79167),
+    tolerance = 1e-3
+  )
+  expect_equal(
+    head(out$Petal.Length),
+    head(iris$Petal.Length),
+    tolerance = 1e-3
+  )
   expect_identical(
     colnames(out),
     c(
-      "Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width",
-      "Species", "Sepal.Width_r", "Sepal.Length_r"
+      "Sepal.Length",
+      "Sepal.Width",
+      "Petal.Length",
+      "Petal.Width",
+      "Species",
+      "Sepal.Width_r",
+      "Sepal.Length_r"
     )
   )
 
@@ -89,13 +136,26 @@ test_that("rescale works grouped df and append", {
 
   x <- poorman::group_by(iris, Species)
   out <- rescale(x, to = c(0, 1), select = starts_with("Sepal"), append = TRUE)
-  expect_equal(head(out$Sepal.Width_r), c(0.57143, 0.33333, 0.42857, 0.38095, 0.61905, 0.7619), tolerance = 1e-3)
-  expect_equal(head(out$Petal.Length), head(iris$Petal.Length), tolerance = 1e-3)
+  expect_equal(
+    head(out$Sepal.Width_r),
+    c(0.57143, 0.33333, 0.42857, 0.38095, 0.61905, 0.7619),
+    tolerance = 1e-3
+  )
+  expect_equal(
+    head(out$Petal.Length),
+    head(iris$Petal.Length),
+    tolerance = 1e-3
+  )
   expect_identical(
     colnames(out),
     c(
-      "Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width",
-      "Species", "Sepal.Length_r", "Sepal.Width_r"
+      "Sepal.Length",
+      "Sepal.Width",
+      "Petal.Length",
+      "Petal.Width",
+      "Species",
+      "Sepal.Length_r",
+      "Sepal.Width_r"
     )
   )
 })
@@ -120,7 +180,11 @@ test_that("data_rescale can expand range", {
     c(4.5, 5.6, 6.7, 7.8, 8.9, 10, 11.1, 12.2, 13.3, 14.4, 15.5),
     ignore_attr = TRUE
   )
-  expect_equal(rescale(x, multiply = 1.1), rescale(x, add = 0.5), ignore_attr = TRUE)
+  expect_equal(
+    rescale(x, multiply = 1.1),
+    rescale(x, add = 0.5),
+    ignore_attr = TRUE
+  )
   expect_error(rescale(x, multiply = 0.9, add = 1), regex = "Only one of")
   expect_error(rescale(x, multiply = c(1.2, 1.4)), regex = "The length of")
 
@@ -170,6 +234,9 @@ test_that("data_rescale can expand range", {
   )
 
   expect_error(rescale(d, multiply = 0.9, add = 1), regex = "Only one of")
-  expect_error(rescale(d, multiply = list(x = 0.9, y = 2), add = list(y = 1)), regex = "Only one of")
+  expect_error(
+    rescale(d, multiply = list(x = 0.9, y = 2), add = list(y = 1)),
+    regex = "Only one of"
+  )
   expect_error(rescale(d, multiply = c(0.9, 1.5)), regex = "The length of")
 })
