@@ -1,7 +1,7 @@
 test_that("extract from data frame", {
   x <- c(1, 2, NA, 3, NaN, 4, NA, 5, Inf, -Inf, 6, 7)
 
-  expect_equal(
+  expect_identical(
     replace_nan_inf(x),
     c(1, 2, NA, 3, NA, 4, NA, 5, NA, NA, 6, 7)
   )
@@ -13,7 +13,7 @@ test_that("extract from data frame", {
     stringsAsFactors = FALSE
   )
 
-  expect_equal(
+  expect_identical(
     replace_nan_inf(df),
     structure(
       list(
@@ -24,4 +24,16 @@ test_that("extract from data frame", {
       class = "data.frame"
     )
   )
+
+  expect_identical(
+    replace_nan_inf(df, select = starts_with("x")),
+    structure(
+      list(
+        x = c(1, NA, 5, NA, 2, NA),
+        y = c(3, NaN, 4, -Inf, 6, 7)
+      ),
+      row.names = c(NA, -6L),
+      class = "data.frame"
+    )
+  )
 })
